# test/test_utils.py

import unittest
from zuele.utils import add

class TestAddFunction(unittest.TestCase):
    def test_add(self):
        result = add(3, 5)
        self.assertEqual(result, 8, "加法函数测试失败")

if __name__ == "__main__":
    unittest.main()


# zeule/tokenizer.py

def tokenize(text):
    """
    将输入的文本分割成单词列表。
    目前使用简单的空格分割，后续可以扩展为更复杂的分词算法。
    """
    # 去除文本中的标点符号
    punctuation = '.,!?;:"\''
    for char in punctuation:
        text = text.replace(char, "")

    # 使用空格分割文本
    words = text.split()
    return words


from setuptools import setup,find_packages

setup(
    name='zuele',
    version='0.0.1',
    author='ikun',
    author_email='2206490823@qq.com',
    description='Jieba in economy',
    packages=['zuele'],
    package_dir={'zuele':'zuele'},
)
